# `somacore`: the Python version of the SOMA specification

`somacore` is a (currently in-development) Python interpretation of the [abstract SOMA specification](https://github.com/single-cell-data/SOMA/blob/main/abstract_specification.md).
Like the abstract specification, it is still in flux and in progress, and we gladly accept feedback.
This will evolve in tandem with the abstract spec itself as well as the [initial TileDB-based implementation](https://github.com/single-cell-data/TileDB-SOMA).

For more information about our development process see [this project plan](https://docs.google.com/document/d/1e6L36SS-eazG6tHYwwnCfEfUcx_3dTFJUEE-gGxgFM4/edit).
